==> haskell-pandoc-server-0.1.0.5-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-EQtip1441mC1KwYmpekqHt
key:                  pandoc-server-0.1.0.5-EQtip1441mC1KwYmpekqHt
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  247952eece3182e833ac7253b77713d1
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-EQtip1441mC1KwYmpekqHt
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doctemplates-0.11-Fhxb714ZK1zmCs3plIEub
    pandoc-3.1.8-FRqy0XtYPFNBlb6o1hk7Va
    pandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
    servant-server-0.20-J6CX53tq2Ll7zCXmiHEGBS
    skylighting-0.14-AdXf1bwcHBbKpYStoKm5v3 text-1.2.5.0
    unicode-collation-0.1.3.6-CQRRSp3DARyCZWgBXKOEpR
    wai-3.2.4-10LJs6BzoC32T6ivnufiRP
    wai-cors-0.2.7-C1wJItQC3FbGcb8S0w3GZu

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-server-0.1.0.5-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-9Gn8DV2zT0NGQEYpDiEK1P
key:                  pandoc-server-0.1.0.5-9Gn8DV2zT0NGQEYpDiEK1P
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  144d4a53d8e537aaca9ddd3832d09296
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-9Gn8DV2zT0NGQEYpDiEK1P
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doctemplates-0.11-Fhxb714ZK1zmCs3plIEub
    pandoc-3.1.8-FRqy0XtYPFNBlb6o1hk7Va
    pandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
    servant-server-0.20-8I9IA1EduKDGZyG4jGS3sH
    skylighting-0.14-AdXf1bwcHBbKpYStoKm5v3 text-1.2.5.0
    unicode-collation-0.1.3.6-CQRRSp3DARyCZWgBXKOEpR
    wai-3.2.4-10LJs6BzoC32T6ivnufiRP
    wai-cors-0.2.7-C1wJItQC3FbGcb8S0w3GZu

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
